import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AchieveService } from '../../service/core/achieve.service';
import { CDTO_achieve, CVO_achieve, FVO_achieve, QDTO_achieve, QVO_achieve, UDTO_achieve, UVAO_achieve } from '../../interface/core/achieve.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { CoreUtilService } from '../../service/core/coreUtil.service';
@ApiTags(['成果表'])
@Controller('/achieve')
export class AchieveController extends BaseController {
  @Inject()
  service: AchieveService;
  @Inject()
  coreUtilService: CoreUtilService;

  @Post('/getOwner')
  async getOwner(@Body('owner') owner: string) {
    const data = await this.coreUtilService.getOwner(owner);
    return data;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_achieve })
  async create(@Body() data: CDTO_achieve) {
    const dbData = await this.service.create(data);
    const result = new CVO_achieve(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_achieve })
  async query(@Query() filter: QDTO_achieve, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_achieve(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_achieve })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_achieve(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_achieve })
  async update(@Param('id') id: string, @Body() body: UDTO_achieve) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
