import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DemandService } from '../../service/core/demand.service';
import { CDTO_demand, CVO_demand, FVO_demand, QDTO_demand, QVO_demand, UDTO_demand, UVAO_demand } from '../../interface/core/demand.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { CoreUtilService } from '../../service/core/coreUtil.service';
@ApiTags(['需求信息表'])
@Controller('/demand')
export class DemandController extends BaseController {
  @Inject()
  service: DemandService;
  @Inject()
  coreUtilService: CoreUtilService;

  @Post('/getOwner')
  async getOwner(@Body('owner') owner: string) {
    const data = await this.coreUtilService.getOwner(owner);
    return data;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_demand })
  async create(@Body() data: CDTO_demand) {
    const dbData = await this.service.create(data);
    const result = new CVO_demand(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_demand })
  async query(@Query() filter: QDTO_demand, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_demand(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_demand })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_demand(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_demand })
  async update(@Param('id') id: string, @Body() body: UDTO_demand) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
