import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ServiceService } from '../../service/core/service.service';
import { CDTO_service, CVO_service, FVO_service, QDTO_service, QVO_service, UDTO_service, UVAO_service } from '../../interface/core/service.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { CoreUtilService } from '../../service/core/coreUtil.service';
@ApiTags(['服务内容'])
@Controller('/service')
export class ServiceController extends BaseController {
  @Inject()
  service: ServiceService;
  @Inject()
  coreUtilService: CoreUtilService;

  @Post('/getOwner')
  async getOwner(@Body('owner') owner: string) {
    const data = await this.coreUtilService.getOwner(owner);
    return data;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_service })
  async create(@Body() data: CDTO_service) {
    const dbData = await this.service.create(data);
    const result = new CVO_service(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_service })
  async query(@Query() filter: QDTO_service, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_service(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_service })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_service(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_service })
  async update(@Param('id') id: string, @Body() body: UDTO_service) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
