import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AuctionService } from '../../../service/core/trade/auction.service';
import { CDTO_auction, CVO_auction, FVO_auction, QDTO_auction, QVO_auction, UDTO_auction, UVAO_auction } from '../../../interface/core/trade/auction.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { ListingService } from '../../../service/core/trade/listing.service';
@ApiTags(['拍卖'])
@Controller('/auction')
export class AuctionController extends BaseController {
  @Inject()
  service: AuctionService;
  @Inject()
  listingService: ListingService;

  @Post('/getListingList')
  async getListingList(@Body('ids') ids: Array<string>) {
    const list = await this.listingService.getListByIds(ids);
    return list;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_auction })
  async create(@Body() data: CDTO_auction) {
    const dbData = await this.service.create(data);
    const result = new CVO_auction(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_auction })
  async query(@Query() filter: QDTO_auction, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_auction(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_auction })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_auction(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_auction })
  async update(@Param('id') id: string, @Body() body: UDTO_auction) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
