import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ListingService } from '../../../service/core/trade/listing.service';
import { CDTO_listing, CVO_listing, FVO_listing, QDTO_listing, QVO_listing, UDTO_listing, UVAO_listing } from '../../../interface/core/trade/listing.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['挂牌交易'])
@Controller('/listing')
export class ListingController extends BaseController {
  @Inject()
  service: ListingService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_listing })
  async create(@Body() data: CDTO_listing) {
    const dbData = await this.service.create(data);
    const result = new CVO_listing(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_listing })
  async query(@Query() filter: QDTO_listing, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_listing(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_listing })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_listing(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_listing })
  async update(@Param('id') id: string, @Body() body: UDTO_listing) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
