import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { LinkItemService } from '../../service/service/linkItem.service';
import { CDTO_linkItem, CVO_linkItem, FVO_linkItem, QDTO_linkItem, QVO_linkItem, UDTO_linkItem, UVAO_linkItem } from '../../interface/service/linkItem.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['办事事项'])
@Controller('/linkItem')
export class LinkItemController extends BaseController {
  @Inject()
  service: LinkItemService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_linkItem })
  async create(@Body() data: CDTO_linkItem) {
    const dbData = await this.service.create(data);
    const result = new CVO_linkItem(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_linkItem })
  async query(@Query() filter: QDTO_linkItem, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_linkItem(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_linkItem })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_linkItem(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_linkItem })
  async update(@Param('id') id: string, @Body() body: UDTO_linkItem) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
