import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PolicyService } from '../../service/service/policy.service';
import { CDTO_policy, CVO_policy, FVO_policy, QDTO_policy, QVO_policy, UDTO_policy, UVAO_policy } from '../../interface/service/policy.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['政策法规'])
@Controller('/policy')
export class PolicyController extends BaseController {
  @Inject()
  service: PolicyService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_policy })
  async create(@Body() data: CDTO_policy) {
    const dbData = await this.service.create(data);
    const result = new CVO_policy(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_policy })
  async query(@Query() filter: QDTO_policy, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_policy(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_policy })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_policy(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_policy })
  async update(@Param('id') id: string, @Body() body: UDTO_policy) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
