import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ResearchService } from '../../service/user/research.service';
import { CDTO_research, CVO_research, FVO_research, QDTO_research, QVO_research, UDTO_research, UVAO_research } from '../../interface/user/research.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科研单位表'])
@Controller('/research')
export class ResearchController extends BaseController {
  @Inject()
  service: ResearchService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_research })
  async create(@Body() data: CDTO_research) {
    await this.service.checkIsExist(data);
    const dbData = await this.service.create(data);
    const result = new CVO_research(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_research })
  async query(@Query() filter: QDTO_research, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_research(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_research })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_research(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_research })
  async update(@Param('id') id: string, @Body() body: UDTO_research) {
    await this.service.checkIsExist(body);
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
