import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SelfUserService } from '../../service/user/selfUser.service';
import { CDTO_selfUser, CVO_selfUser, FVO_selfUser, QDTO_selfUser, QVO_selfUser, UDTO_selfUser, UVAO_selfUser } from '../../interface/user/selfUser.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['个人用户表'])
@Controller('/selfUser')
export class SelfUserController extends BaseController {
  @Inject()
  service: SelfUserService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_selfUser })
  async create(@Body() data: CDTO_selfUser) {
    await this.service.checkIsExist(data);
    const dbData = await this.service.create(data);
    const result = new CVO_selfUser(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_selfUser })
  async query(@Query() filter: QDTO_selfUser, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_selfUser(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_selfUser })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_selfUser(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_selfUser })
  async update(@Param('id') id: string, @Body() body: UDTO_selfUser) {
    await this.service.checkIsExist(body);
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
