import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import { SearchBase } from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_demand {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '所属人' })
  'owner': string = undefined;
  @ApiProperty({ description: '需求标题' })
  'title': string = undefined;
  @ApiProperty({ description: '行业领域' })
  'industry_sector': string = undefined;
  @ApiProperty({ description: '需求紧急度' })
  'urgency': string = undefined;
  @ApiProperty({ description: '合作方式' })
  'way': string = undefined;
  @ApiProperty({ description: '需求开始时间' })
  'start_time': string = undefined;
  @ApiProperty({ description: '需求结束时间' })
  'end_time': string = undefined;
  @ApiProperty({ description: '地区' })
  'area': string = undefined;
  @ApiProperty({ description: '需求详情' })
  'desc': string = undefined;
  @ApiProperty({ description: '状态' })
  'status': string = undefined;
}

export class QDTO_demand extends SearchBase {
  constructor() {
    const like_prop = ['title'];
    const props = ['owner', 'title', 'status', 'industry_sector', 'industry_sector[]', 'urgency', 'urgency[]', 'way', 'way[]', 'start_time@start', 'end_time@end', 'area', 'area[]'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '所属人' })
  'owner': string = undefined;
  @ApiProperty({ description: '需求标题' })
  'title': string = undefined;
  @ApiProperty({ description: '状态' })
  'status': string = undefined;
}

export class QVO_demand extends FVO_demand {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_demand {
  @ApiProperty({ description: '所属人' })
  @Rule(RuleType['string']().empty(''))
  'owner': string = undefined;
  @ApiProperty({ description: '需求标题' })
  @Rule(RuleType['string']().empty(''))
  'title': string = undefined;
  @ApiProperty({ description: '行业领域' })
  @Rule(RuleType['string']().empty(''))
  'industry_sector': string = undefined;
  @ApiProperty({ description: '需求紧急度' })
  @Rule(RuleType['string']().empty(''))
  'urgency': string = undefined;
  @ApiProperty({ description: '合作方式' })
  @Rule(RuleType['string']().empty(''))
  'way': string = undefined;
  @ApiProperty({ description: '需求开始时间' })
  @Rule(RuleType['string']().empty(''))
  'start_time': string = undefined;
  @ApiProperty({ description: '需求结束时间' })
  @Rule(RuleType['string']().empty(''))
  'end_time': string = undefined;
  @ApiProperty({ description: '地区' })
  @Rule(RuleType['string']().empty(''))
  'area': string = undefined;
  @ApiProperty({ description: '需求详情' })
  @Rule(RuleType['string']().empty(''))
  'desc': string = undefined;
  @ApiProperty({ description: '状态' })
  @Rule(RuleType['string']().empty(''))
  'status': string = undefined;
}

export class CVO_demand extends FVO_demand {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_demand extends CDTO_demand {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_demand extends FVO_demand {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
