import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { FrameworkErrorEnum, ServiceError } from 'free-midway-component';
import { Demand } from '../../entity/core/demand.entity';
import { Unit } from '../../entity/user/unit.entity';
import { SelfUser } from '../../entity/user/selfUser.entity';
import get = require('lodash/get');
import { Research } from '../../entity/user/research.entity';

@Provide()
export class CoreUtilService {
  @InjectEntityModel(Demand)
  model: ReturnModelType<typeof Demand>;
  @InjectEntityModel(Unit)
  unitModel: ReturnModelType<typeof Unit>;
  @InjectEntityModel(SelfUser)
  selfUserModel: ReturnModelType<typeof SelfUser>;
  @InjectEntityModel(Research)
  researchModel: ReturnModelType<typeof Research>;
  async getOwner(ownerId: string) {
    let data = await this.selfUserModel.findById(ownerId).lean();
    if (data) return get(data, 'nick_name');
    else {
      data = await this.unitModel.findById(ownerId).lean();
      if (!data) data = await this.researchModel.findById(ownerId).lean();
      const name = get(data, 'unit_name');
      if (!name) throw new ServiceError('为找到所属人信息!', FrameworkErrorEnum.NOT_FOUND_DATA);
      return name;
    }
  }
}
